@@ -25,37 +25,22 @@ import (
 	"testing"
 	"time"
 
+	"knative.dev/serving/pkg/apis/config"
+
 	// Inject the fakes for informers this controller relies on.
-	fakecachingclient "github.com/knative/caching/pkg/client/injection/client/fake"
-	fakeimageinformer "github.com/knative/caching/pkg/client/injection/informers/caching/v1alpha1/image/fake"
-	fakekubeclient "github.com/knative/pkg/injection/clients/kubeclient/fake"
-	fakedeploymentinformer "github.com/knative/pkg/injection/informers/kubeinformers/appsv1/deployment/fake"
-	_ "github.com/knative/pkg/injection/informers/kubeinformers/corev1/configmap/fake"
-	fakeendpointsinformer "github.com/knative/pkg/injection/informers/kubeinformers/corev1/endpoints/fake"
-	_ "github.com/knative/pkg/injection/informers/kubeinformers/corev1/service/fake"
-	fakeservingclient "github.com/knative/serving/pkg/client/injection/client/fake"
-	fakekpainformer "github.com/knative/serving/pkg/client/injection/informers/autoscaling/v1alpha1/podautoscaler/fake"
-	fakerevisioninformer "github.com/knative/serving/pkg/client/injection/informers/serving/v1alpha1/revision/fake"
+	fakecachingclient "knative.dev/caching/pkg/client/injection/client/fake"
+	fakeimageinformer "knative.dev/caching/pkg/client/injection/informers/caching/v1alpha1/image/fake"
+	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
+	fakedeploymentinformer "knative.dev/pkg/client/injection/kube/informers/apps/v1/deployment/fake"
+	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/configmap/fake"
+	fakeendpointsinformer "knative.dev/pkg/client/injection/kube/informers/core/v1/endpoints/fake"
+	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/service/fake"
+	fakeservingclient "knative.dev/serving/pkg/client/injection/client/fake"
+	fakepainformer "knative.dev/serving/pkg/client/injection/informers/autoscaling/v1alpha1/podautoscaler/fake"
+	fakerevisioninformer "knative.dev/serving/pkg/client/injection/informers/serving/v1alpha1/revision/fake"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-containerregistry/pkg/authn/k8schain"
-	"github.com/knative/pkg/apis"
-	"github.com/knative/pkg/configmap"
-	"github.com/knative/pkg/controller"
-	"github.com/knative/pkg/kmeta"
-	"github.com/knative/pkg/logging"
-	logtesting "github.com/knative/pkg/logging/testing"
-	"github.com/knative/pkg/metrics"
-	_ "github.com/knative/pkg/metrics/testing"
-	"github.com/knative/pkg/system"
-	av1alpha1 "github.com/knative/serving/pkg/apis/autoscaling/v1alpha1"
-	"github.com/knative/serving/pkg/apis/serving"
-	"github.com/knative/serving/pkg/apis/serving/v1alpha1"
-	"github.com/knative/serving/pkg/autoscaler"
-	"github.com/knative/serving/pkg/deployment"
-	"github.com/knative/serving/pkg/network"
-	"github.com/knative/serving/pkg/reconciler/revision/resources"
-	resourcenames "github.com/knative/serving/pkg/reconciler/revision/resources/names"
 	"golang.org/x/sync/errgroup"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -64,8 +49,25 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/client-go/tools/record"
+	"knative.dev/pkg/apis"
+	"knative.dev/pkg/configmap"
+	"knative.dev/pkg/controller"
+	"knative.dev/pkg/kmeta"
+	"knative.dev/pkg/logging"
+	"knative.dev/pkg/metrics"
+	_ "knative.dev/pkg/metrics/testing"
+	"knative.dev/pkg/system"
+	tracingconfig "knative.dev/pkg/tracing/config"
+	av1alpha1 "knative.dev/serving/pkg/apis/autoscaling/v1alpha1"
+	"knative.dev/serving/pkg/apis/serving"
+	"knative.dev/serving/pkg/apis/serving/v1alpha1"
+	"knative.dev/serving/pkg/autoscaler"
+	"knative.dev/serving/pkg/deployment"
+	"knative.dev/serving/pkg/network"
+	"knative.dev/serving/pkg/reconciler/revision/resources"
+	resourcenames "knative.dev/serving/pkg/reconciler/revision/resources/names"
 
-	. "github.com/knative/pkg/reconciler/testing"
+	. "knative.dev/pkg/reconciler/testing"
 )
 
 func testConfiguration() *v1alpha1.Configuration {
@@ -99,12 +101,12 @@ func testReadyEndpoints(revName string) *corev1.Endpoints {
 	}
 }
 
-func testReadyKPA(rev *v1alpha1.Revision) *av1alpha1.PodAutoscaler {
-	kpa := resources.MakeKPA(rev)
-	kpa.Status.InitializeConditions()
-	kpa.Status.MarkActive()
-	kpa.Status.ServiceName = serviceName(rev.Name)
-	return kpa
+func testReadyPA(rev *v1alpha1.Revision) *av1alpha1.PodAutoscaler {
+	pa := resources.MakePA(rev)
+	pa.Status.InitializeConditions()
+	pa.Status.MarkActive()
+	pa.Status.ServiceName = serviceName(rev.Name)
+	return pa
 }
 
 func newTestControllerWithConfig(t *testing.T, deploymentConfig *deployment.Config, configs ...*corev1.ConfigMap) (
@@ -141,27 +143,36 @@ func newTestControllerWithConfig(t *testing.T, deploymentConfig *deployment.Conf
 		Data: map[string]string{
 			"logging.enable-var-log-collection": "true",
 		},
+	}, {
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: system.Namespace(),
+			Name:      tracingconfig.ConfigName,
+		},
+		Data: map[string]string{
+			"enable":          "true",
+			"debug":           "true",
+			"zipkin-endpoint": "http://zipkin.istio-system.svc.cluster.local:9411/api/v2/spans",
+		},
 	}, {
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: system.Namespace(),
 			Name:      autoscaler.ConfigName,
 		},
 		Data: map[string]string{
-			"max-scale-up-rate":                       "1.0",
+			"max-scale-up-rate":                       "11.0",
 			"container-concurrency-target-percentage": "0.5",
 			"container-concurrency-target-default":    "10.0",
 			"stable-window":                           "5m",
 			"panic-window":                            "10s",
 			"tick-interval":                           "2s",
 		},
-	}, getTestDeploymentConfigMap()}
+	}, getTestDeploymentConfigMap(), getTestDefaultsConfigMap()}
 
 	cms = append(cms, configs...)
 
 	for _, configMap := range cms {
 		configMapWatcher.OnChange(configMap)
 	}
-
 	return ctx, informers, controller, configMapWatcher
 }
 
@@ -210,14 +221,14 @@ func addResourcesToInformers(t *testing.T, ctx context.Context, rev *v1alpha1.Re
 
 	ns := rev.Namespace
 
-	kpaName := resourcenames.KPA(rev)
-	kpa, err := fakeservingclient.Get(ctx).AutoscalingV1alpha1().PodAutoscalers(rev.Namespace).Get(kpaName, metav1.GetOptions{})
+	paName := resourcenames.PA(rev)
+	pa, err := fakeservingclient.Get(ctx).AutoscalingV1alpha1().PodAutoscalers(rev.Namespace).Get(paName, metav1.GetOptions{})
 	if apierrs.IsNotFound(err) && haveBuild {
 		// If we're doing a Build this won't exist yet.
 	} else if err != nil {
-		t.Errorf("PodAutoscalers.Get(%v) = %v", kpaName, err)
+		t.Errorf("PodAutoscalers.Get(%v) = %v", paName, err)
 	} else {
-		fakekpainformer.Get(ctx).Informer().GetIndexer().Add(kpa)
+		fakepainformer.Get(ctx).Informer().GetIndexer().Add(pa)
 	}
 
 	imageName := resourcenames.ImageCache(rev)
@@ -240,7 +251,7 @@ func addResourcesToInformers(t *testing.T, ctx context.Context, rev *v1alpha1.Re
 		fakedeploymentinformer.Get(ctx).Informer().GetIndexer().Add(deployment)
 	}
 
-	return rev, deployment, kpa
+	return rev, deployment, pa
 }
 
 type fixedResolver struct {
@@ -252,19 +263,20 @@ func (r *fixedResolver) Resolve(_ string, _ k8schain.Options, _ sets.String) (st
 }
 
 type errorResolver struct {
-	error string
+	err error
 }
 
 func (r *errorResolver) Resolve(_ string, _ k8schain.Options, _ sets.String) (string, error) {
-	return "", errors.New(r.error)
+	return "", r.err
 }
 
 func TestResolutionFailed(t *testing.T) {
-	ctx, _, controller, _ := newTestController(t)
+	ctx, cancel, _, controller, _ := newTestController(t)
+	defer cancel()
 
 	// Unconditionally return this error during resolution.
-	errorMessage := "I am the expected error message, hear me ROAR!"
-	controller.Reconciler.(*Reconciler).resolver = &errorResolver{errorMessage}
+	innerError := errors.New("i am the expected error message, hear me ROAR!")
+	controller.Reconciler.(*Reconciler).resolver = &errorResolver{innerError}
 
 	rev := testRevision()
 	config := testConfiguration()
@@ -285,7 +297,7 @@ func TestResolutionFailed(t *testing.T) {
 			Status: corev1.ConditionFalse,
 			Reason: "ContainerMissing",
 			Message: v1alpha1.RevisionContainerMissingMessage(
-				rev.Spec.GetContainer().Image, errorMessage),
+				rev.Spec.GetContainer().Image, "failed to resolve image to digest: "+innerError.Error()),
 			LastTransitionTime: got.LastTransitionTime,
 			Severity:           apis.ConditionSeverityError,
 		}
@@ -340,7 +352,8 @@ func TestUpdateRevWithWithUpdatedLoggingURL(t *testing.T) {
 
 // TODO(mattmoor): Remove when we have coverage of EnqueueEndpointsRevision
 func TestMarkRevReadyUponEndpointBecomesReady(t *testing.T) {
-	ctx, _, controller, _ := newTestController(t)
+	ctx, cancel, _, controller, _ := newTestController(t)
+	defer cancel()
 	rev := testRevision()
 
 	fakeRecorder := controller.Reconciler.(*Reconciler).Base.Recorder.(*record.FakeRecorder)
@@ -367,8 +380,8 @@ func TestMarkRevReadyUponEndpointBecomesReady(t *testing.T) {
 
 	endpoints := testReadyEndpoints(rev.Name)
 	fakeendpointsinformer.Get(ctx).Informer().GetIndexer().Add(endpoints)
-	kpa := testReadyKPA(rev)
-	fakekpainformer.Get(ctx).Informer().GetIndexer().Add(kpa)
+	pa := testReadyPA(rev)
+	fakepainformer.Get(ctx).Informer().GetIndexer().Add(pa)
 	f := controller.EnqueueLabelOfNamespaceScopedResource("", serving.RevisionLabelKey)
 	f(endpoints)
 	if err := controller.Reconciler.Reconcile(context.Background(), KeyOrDie(rev)); err != nil {
@@ -404,7 +417,8 @@ func TestMarkRevReadyUponEndpointBecomesReady(t *testing.T) {
 }
 
 func TestNoQueueSidecarImageUpdateFail(t *testing.T) {
-	ctx, _, controller, watcher := newTestController(t)
+	ctx, cancel, _, controller, watcher := newTestController(t)
+	defer cancel()
 
 	rev := testRevision()
 	config := testConfiguration()
@@ -507,7 +521,6 @@ func getPodAnnotationsForConfig(t *testing.T, configMapValue string, configAnnot
 }
 
 func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
-	defer logtesting.ClearAll()
 	// Test that changes to the ConfigMap result in the desired changes on an existing
 	// revision.
 	tests := []struct {
@@ -541,6 +554,32 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 				return HookIncomplete
 			}
 		},
+	}, {
+		name: "Update ContainerConcurrency", // Should update ContainerConcurrency on revision spec
+		configMapToUpdate: &corev1.ConfigMap{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: system.Namespace(),
+				Name:      config.DefaultsConfigName,
+			},
+			Data: map[string]string{
+				"container-concurrency": "3",
+			},
+		},
+		callback: func(t *testing.T) func(runtime.Object) HookResult {
+			return func(obj runtime.Object) HookResult {
+				revision := obj.(*v1alpha1.Revision)
+				t.Logf("Revision updated: %v", revision.Name)
+
+				expected := int64(3)
+				got := *(revision.Spec.ContainerConcurrency)
+				if got != expected {
+					return HookComplete
+				}
+
+				t.Logf("No update occurred; expected: %d got: %d", expected, got)
+				return HookIncomplete
+			}
+		},
 	}}
 
 	for _, test := range tests {
@@ -550,12 +589,6 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 
 			ctx, cancel := context.WithCancel(ctx)
 			grp := errgroup.Group{}
-			defer func() {
-				cancel()
-				if err := grp.Wait(); err != nil {
-					t.Errorf("Wait() = %v", err)
-				}
-			}()
 
 			servingClient := fakeservingclient.Get(ctx)
 
@@ -566,9 +599,18 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 
 			h.OnUpdate(&servingClient.Fake, "revisions", test.callback(t))
 
-			if err := controller.StartInformers(ctx.Done(), informers...); err != nil {
+			waitInformers, err := controller.RunInformers(ctx.Done(), informers...)
+			if err != nil {
 				t.Fatalf("Failed to start informers: %v", err)
 			}
+			defer func() {
+				cancel()
+				if err := grp.Wait(); err != nil {
+					t.Errorf("Wait() = %v", err)
+				}
+				waitInformers()
+			}()
+
 			if err := watcher.Start(ctx.Done()); err != nil {
 				t.Fatalf("Failed to start configuration manager: %v", err)
 			}
@@ -587,7 +629,6 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 }
 
 func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
-	defer logtesting.ClearAll()
 	// Test that changes to the ConfigMap result in the desired changes on an existing
 	// deployment.
 	tests := []struct {
@@ -704,12 +745,6 @@ func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
 
 			ctx, cancel := context.WithCancel(ctx)
 			grp := errgroup.Group{}
-			defer func() {
-				cancel()
-				if err := grp.Wait(); err != nil {
-					t.Errorf("Wait() = %v", err)
-				}
-			}()
 
 			kubeClient := fakekubeclient.Get(ctx)
 
@@ -725,9 +760,18 @@ func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
 				return HookComplete
 			})
 
-			if err := controller.StartInformers(ctx.Done(), informers...); err != nil {
+			waitInformers, err := controller.RunInformers(ctx.Done(), informers...)
+			if err != nil {
 				t.Fatalf("Failed to start informers: %v", err)
 			}
+			defer func() {
+				cancel()
+				if err := grp.Wait(); err != nil {
+					t.Errorf("Wait() = %v", err)
+				}
+				waitInformers()
+			}()
+
 			if err := watcher.Start(ctx.Done()); err != nil {
 				t.Fatalf("Failed to start configuration manager: %v", err)
 			}
